@@ -24,16 +24,10 @@
  * ```
  */
 #![allow(clippy::field_reassign_with_default)]
-use std::collections::HashMap;
-use std::env;
-use std::error;
-use std::fmt;
-use std::fmt::Debug;
-use std::sync::Arc;
+#![allow(clippy::nonstandard_macro_braces)]
+use std::{collections::HashMap, env, error, fmt, fmt::Debug, sync::Arc};
 
-use chrono::offset::Utc;
-use chrono::serde::ts_seconds;
-use chrono::DateTime;
+use chrono::{offset::Utc, serde::ts_seconds, DateTime};
 use reqwest::{header, Body, Client, Method, Request, StatusCode, Url};
 use schemars::JsonSchema;
 use serde::{Deserialize, Serialize};
@@ -60,7 +54,14 @@ impl Slack {
     /// Create a new Slack client struct. It takes a type that can convert into
     /// an &str (`String` or `Vec<u8>` for example). As long as the function is
     /// given a valid API Token and Workspace ID your requests will work.
-    pub fn new<I, K, B, R, T, Q>(client_id: I, client_secret: K, workspace_id: B, redirect_uri: R, token: T, user_token: Q) -> Self
+    pub fn new<I, K, B, R, T, Q>(
+        client_id: I,
+        client_secret: K,
+        workspace_id: B,
+        redirect_uri: R,
+        token: T,
+        user_token: Q,
+    ) -> Self
     where
         I: ToString,
         K: ToString,
@@ -114,7 +115,14 @@ impl Slack {
         Slack::new(client_id, client_secret, workspace_id, redirect_uri, token, user_token)
     }
 
-    fn request<B>(&self, token: &str, method: Method, path: &str, body: B, query: Option<Vec<(&str, String)>>) -> Request
+    fn request<B>(
+        &self,
+        token: &str,
+        method: Method,
+        path: &str,
+        body: B,
+        query: Option<Vec<(&str, String)>>,
+    ) -> Request
     where
         B: Serialize,
     {
@@ -127,7 +135,10 @@ impl Slack {
         // Set the default headers.
         let mut headers = header::HeaderMap::new();
         headers.append(header::AUTHORIZATION, bearer);
-        headers.append(header::CONTENT_TYPE, header::HeaderValue::from_static("application/json"));
+        headers.append(
+            header::CONTENT_TYPE,
+            header::HeaderValue::from_static("application/json"),
+        );
 
         let mut rb = self.client.request(method.clone(), url).headers(headers);
 
@@ -151,7 +162,11 @@ impl Slack {
         let state = uuid::Uuid::new_v4();
         format!(
             "https://slack.com/oauth/v2/authorize?scope={}&client_id={}&user_scope={}&redirect_uri={}&state={}",
-            "commands,incoming-webhook,team:read,users:read,users:read.email,users.profile:read", self.client_id, "identity.basic,identity.email", self.redirect_uri, state
+            "commands,incoming-webhook,team:read,users:read,users:read.email,users.profile:read",
+            self.client_id,
+            "identity.basic,identity.email",
+            self.redirect_uri,
+            state
         )
     }
 
@@ -191,7 +206,13 @@ impl Slack {
     pub async fn list_users(&self) -> Result<Vec<User>, APIError> {
         // Build the request.
         // TODO: paginate.
-        let request = self.request(&self.token, Method::GET, "users.list", (), Some(vec![("limit", "100".to_string())]));
+        let request = self.request(
+            &self.token,
+            Method::GET,
+            "users.list",
+            (),
+            Some(vec![("limit", "100".to_string())]),
+        );
 
         let resp = self.client.execute(request).await.unwrap();
         match resp.status() {
@@ -303,7 +324,10 @@ impl Slack {
             &self.user_token,
             Method::POST,
             "users.profile.set",
-            UpdateUserProfileRequest { user: user_id.to_string(), profile },
+            UpdateUserProfileRequest {
+                user: user_id.to_string(),
+                profile,
+            },
             None,
         );
 
@@ -322,9 +346,9 @@ impl Slack {
     }
 
     /// Post text to a channel.
-    pub async fn post_to_channel(url: String, v: Value) -> Result<(), APIError> {
+    pub async fn post_to_channel(url: &str, v: &Value) -> Result<(), APIError> {
         let client = Client::new();
-        let resp = client.post(&url).body(Body::from(v.to_string())).send().await.unwrap();
+        let resp = client.post(url).body(Body::from(v.to_string())).send().await.unwrap();
 
         match resp.status() {
             StatusCode::OK => (),
@@ -348,13 +372,23 @@ pub struct APIError {
 
 impl fmt::Display for APIError {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
-        write!(f, "APIError: status code -> {}, body -> {}", self.status_code.to_string(), self.body)
+        write!(
+            f,
+            "APIError: status code -> {}, body -> {}",
+            self.status_code.to_string(),
+            self.body
+        )
     }
 }
 
 impl fmt::Debug for APIError {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
-        write!(f, "APIError: status code -> {}, body -> {}", self.status_code.to_string(), self.body)
+        write!(
+            f,
+            "APIError: status code -> {}, body -> {}",
+            self.status_code.to_string(),
+            self.body
+        )
     }
 }
 
@@ -530,7 +564,10 @@ pub struct MessageAttachment {
     pub title: String,
     #[serde(default, skip_serializing_if = "String::is_empty")]
     pub title_link: String,
-    #[serde(deserialize_with = "ts_seconds::deserialize", serialize_with = "ts_seconds::serialize")]
+    #[serde(
+        deserialize_with = "ts_seconds::deserialize",
+        serialize_with = "ts_seconds::serialize"
+    )]
     pub ts: DateTime<Utc>,
 }
 
